@@ -1,4 +1,6 @@
-from __future__ import print_function
+#!/usr/bin/env python
+
+
 __license__   = 'GPL v3'
 __copyright__ = '2008, Kovid Goyal <kovid at kovidgoyal.net>'
 """
@@ -7,14 +9,16 @@ Provides a command-line interface to ebook devices.
 For usage information run the script.
 """
 
-import StringIO, sys, time, os
+import sys, time, os
 from optparse import OptionParser
 
-from calibre import __version__, __appname__, human_readable, fsync
+from calibre import __version__, __appname__, human_readable, fsync, prints
 from calibre.devices.errors import ArgumentError, DeviceError, DeviceLocked
 from calibre.customize.ui import device_plugins
 from calibre.devices.scanner import DeviceScanner
 from calibre.utils.config import device_prefs
+from polyglot.builtins import unicode_type
+from polyglot.io import PolyglotStringIO
 
 MINIMUM_COL_WIDTH = 12  # : Minimum width of columns in ls output
 
@@ -30,73 +34,55 @@ class FileFormatter(object):
         self.name        = file.name
         self.path        = file.path
 
-    @dynamic_property
+    @property
     def mode_string(self):
-        doc=""" The mode string for this file. There are only two modes read-only and read-write """
+        """ The mode string for this file. There are only two modes read-only and read-write """
+        mode, x = "-", "-"
+        if self.is_dir:
+            mode, x = "d", "x"
+        if self.is_readonly:
+            mode += "r-"+x+"r-"+x+"r-"+x
+        else:
+            mode += "rw"+x+"rw"+x+"rw"+x
+        return mode
 
-        def fget(self):
-            mode, x = "-", "-"
-            if self.is_dir:
-                mode, x = "d", "x"
-            if self.is_readonly:
-                mode += "r-"+x+"r-"+x+"r-"+x
-            else:
-                mode += "rw"+x+"rw"+x+"rw"+x
-            return mode
-        return property(doc=doc, fget=fget)
-
-    @dynamic_property
+    @property
     def isdir_name(self):
-        doc='''Return self.name + '/' if self is a directory'''
+        '''Return self.name + '/' if self is a directory'''
+        name = self.name
+        if self.is_dir:
+            name += '/'
+        return name
 
-        def fget(self):
-            name = self.name
-            if self.is_dir:
-                name += '/'
-            return name
-        return property(doc=doc, fget=fget)
-
-    @dynamic_property
+    @property
     def name_in_color(self):
-        doc=""" The name in ANSI text. Directories are blue, ebooks are green """
+        """ The name in ANSI text. Directories are blue, ebooks are green """
+        cname = self.name
+        blue, green, normal = "", "", ""
+        if self.term:
+            blue, green, normal = self.term.BLUE, self.term.GREEN, self.term.NORMAL
+        if self.is_dir:
+            cname = blue + self.name + normal
+        else:
+            ext = self.name[self.name.rfind("."):]
+            if ext in (".pdf", ".rtf", ".lrf", ".lrx", ".txt"):
+                cname = green + self.name + normal
+        return cname
 
-        def fget(self):
-            cname = self.name
-            blue, green, normal = "", "", ""
-            if self.term:
-                blue, green, normal = self.term.BLUE, self.term.GREEN, self.term.NORMAL
-            if self.is_dir:
-                cname = blue + self.name + normal
-            else:
-                ext = self.name[self.name.rfind("."):]
-                if ext in (".pdf", ".rtf", ".lrf", ".lrx", ".txt"):
-                    cname = green + self.name + normal
-            return cname
-        return property(doc=doc, fget=fget)
-
-    @dynamic_property
+    @property
     def human_readable_size(self):
-        doc=""" File size in human readable form """
+        """ File size in human readable form """
+        return human_readable(self.size)
 
-        def fget(self):
-            return human_readable(self.size)
-        return property(doc=doc, fget=fget)
-
-    @dynamic_property
+    @property
     def modification_time(self):
-        doc=""" Last modified time in the Linux ls -l format """
+        """ Last modified time in the Linux ls -l format """
+        return time.strftime("%Y-%m-%d %H:%M", time.localtime(self.wtime))
 
-        def fget(self):
-            return time.strftime("%Y-%m-%d %H:%M", time.localtime(self.wtime))
-        return property(doc=doc, fget=fget)
-
-    @dynamic_property
+    @property
     def creation_time(self):
-        doc=""" Last modified time in the Linux ls -l format """
-
-        def fget(self):
-            return time.strftime("%Y-%m-%d %H:%M", time.localtime(self.ctime))
-        return property(doc=doc, fget=fget)
+        """ Last modified time in the Linux ls -l format """
+        return time.strftime("%Y-%m-%d %H:%M", time.localtime(self.ctime))
 
 
 def info(dev):
@@ -109,7 +95,7 @@ def info(dev):
 
 def ls(dev, path, recurse=False, human_readable_size=False, ll=False, cols=0):
     def col_split(l, cols):  # split list l into columns
-        rows = len(l) / cols
+        rows = len(l) // cols
         if len(l) % cols:
             rows += 1
         m = []
@@ -127,19 +113,19 @@ def ls(dev, path, recurse=False, human_readable_size=False, ll=False, cols=0):
                 c += 1
         return rowwidths
 
-    output = StringIO.StringIO()
+    output = PolyglotStringIO()
     if path.endswith("/") and len(path) > 1:
         path = path[:-1]
     dirs = dev.list(path, recurse)
     for dir in dirs:
         if recurse:
-            print(dir[0] + ":", file=output)
+            prints(dir[0] + ":", file=output)
         lsoutput, lscoloutput = [], []
         files = dir[1]
         maxlen = 0
         if ll:  # Calculate column width for size column
             for file in files:
-                size = len(str(file.size))
+                size = len(unicode_type(file.size))
                 if human_readable_size:
                     file = FileFormatter(file)
                     size = len(file.human_readable_size)
@@ -151,14 +137,14 @@ def ls(dev, path, recurse=False, human_readable_size=False, ll=False, cols=0):
             lsoutput.append(name)
             lscoloutput.append(name)
             if ll:
-                size = str(file.size)
+                size = unicode_type(file.size)
                 if human_readable_size:
                     size = file.human_readable_size
-                print(file.mode_string, ("%"+str(maxlen)+"s")%size, file.modification_time, name, file=output)
+                prints(file.mode_string, ("%"+unicode_type(maxlen)+"s")%size, file.modification_time, name, file=output)
         if not ll and len(lsoutput) > 0:
             trytable = []
             for colwidth in range(MINIMUM_COL_WIDTH, cols):
-                trycols = int(cols/colwidth)
+                trycols = int(cols//colwidth)
                 trytable = col_split(lsoutput, trycols)
                 works = True
                 for row in trytable:
@@ -176,10 +162,10 @@ def ls(dev, path, recurse=False, human_readable_size=False, ll=False, cols=0):
             for r in range(len(trytable)):
                 for c in range(len(trytable[r])):
                     padding = rowwidths[c] - len(trytable[r][c])
-                    print(trytablecol[r][c], "".ljust(padding), end=' ', file=output)
-                print(file=output)
-        print(file=output)
-    listing = output.getvalue().rstrip()+ "\n"
+                    prints(trytablecol[r][c], "".ljust(padding), end=' ', file=output)
+                prints(file=output)
+        prints(file=output)
+    listing = output.getvalue().rstrip() + "\n"
     output.close()
     return listing
 
@@ -258,7 +244,7 @@ def main():
             print("Filesystem\tSize \tUsed \tAvail \tUse%")
             for i in range(3):
                 print("%-10s\t%s\t%s\t%s\t%s"%(where[i], human_readable(total[i]), human_readable(total[i]-free[i]), human_readable(free[i]),
-                                                                            str(0 if total[i]==0 else int(100*(total[i]-free[i])/(total[i]*1.)))+"%"))
+                                                                            unicode_type(0 if total[i]==0 else int(100*(total[i]-free[i])/(total[i]*1.)))+"%"))
         elif command == 'eject':
             dev.eject()
         elif command == "books":
@@ -272,7 +258,7 @@ def main():
             for book in dev.books(oncard='cardb'):
                 print(book)
         elif command == "mkdir":
-            parser = OptionParser(usage="usage: %prog mkdir [options] path\nCreate a directory on the device\n\npath must begin with / or card:/")
+            parser = OptionParser(usage="usage: %prog mkdir [options] path\nCreate a folder on the device\n\npath must begin with / or card:/")
             if len(args) != 1:
                 parser.print_help()
                 sys.exit(1)
@@ -281,8 +267,8 @@ def main():
             parser = OptionParser(usage="usage: %prog ls [options] path\nList files on the device\n\npath must begin with / or card:/")
             parser.add_option(
                 "-l", help="In addition to the name of each file, print the file type, permissions, and  timestamp  (the  modification time, in the local timezone). Times are local.",  # noqa
-                              dest="ll", action="store_true", default=False)
-            parser.add_option("-R", help="Recursively list subdirectories encountered. /dev and /proc are omitted",
+                dest="ll", action="store_true", default=False)
+            parser.add_option("-R", help="Recursively list subfolders encountered. /dev and /proc are omitted",
                               dest="recurse", action="store_true", default=False)
             parser.remove_option("-h")
             parser.add_option("-h", "--human-readable", help="show sizes in human readable format", dest="hrs", action="store_true", default=False)
@@ -299,7 +285,7 @@ def main():
             "dev:mountpoint/my/path\n"+\
             "where mountpoint is one of / or carda: or cardb:/\n\n"+\
             "source must point to a file for which you have read permissions\n"+\
-            "destination must point to a file or directory for which you have write permissions"
+            "destination must point to a file or folder for which you have write permissions"
             parser = OptionParser(usage=usage)
             parser.add_option('-f', '--force', dest='force', action='store_true', default=False,
                               help='Overwrite the destination file if it exists already.')
@@ -350,7 +336,7 @@ def main():
             outfile = sys.stdout
             dev.get_file(path, outfile)
         elif command == "rm":
-            parser = OptionParser(usage="usage: %prog rm path\nDelete files from the device\n\npath should point to a file or empty directory on the device "+
+            parser = OptionParser(usage="usage: %prog rm path\nDelete files from the device\n\npath should point to a file or empty folder on the device "+
                                   "and must begin with / or card:/\n\n"+
                                   "rm will DELETE the file. Be very CAREFUL")
             options, args = parser.parse_args(args)
