@@ -1,6 +1,6 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 # vim:fileencoding=utf-8
-from __future__ import absolute_import, division, print_function, unicode_literals
+
 
 __license__ = 'GPL v3'
 __copyright__ = '2013, Kovid Goyal <kovid at kovidgoyal.net>'
@@ -12,7 +12,7 @@ from calibre.ptempfile import TemporaryDirectory
 from calibre.ptempfile import PersistentTemporaryDirectory
 from calibre.utils.logging import DevNull
 import calibre.ebooks.oeb.polish.container as pc
-from polyglot.builtins import iteritems
+from polyglot.builtins import iteritems, unicode_type
 
 
 def get_cache():
@@ -24,7 +24,7 @@ def get_cache():
 
 
 def needs_recompile(obj, srcs):
-    if isinstance(srcs, type('')):
+    if isinstance(srcs, unicode_type):
         srcs = [srcs]
     try:
         obj_mtime = os.stat(obj).st_mtime
@@ -56,7 +56,8 @@ def get_simple_book(fmt='epub'):
     if needs_recompile(ans, src):
         with TemporaryDirectory('bpt') as tdir:
             with CurrentDir(tdir):
-                raw = lopen(src, 'rb').read().decode('utf-8')
+                with lopen(src, 'rb') as sf:
+                    raw = sf.read().decode('utf-8')
                 raw = add_resources(raw, {
                     'LMONOI': P('fonts/liberation/LiberationMono-Italic.ttf'),
                     'LMONOR': P('fonts/liberation/LiberationMono-Regular.ttf'),
