@@ -1,7 +1,6 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 # vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:ai
-from __future__ import (unicode_literals, division, absolute_import,
-                        print_function)
+
 
 __license__ = 'GPL v3'
 __copyright__ = '2012, Kovid Goyal <kovid@kovidgoyal.net>'
@@ -17,20 +16,22 @@ from calibre.library import current_library_name
 from calibre.library.catalogs import AuthorSortMismatchException, EmptyCatalogException
 from calibre.ptempfile import PersistentTemporaryFile
 from calibre.utils.localization import calibre_langcode_to_name, canonicalize_lang, get_lang
+from polyglot.builtins import unicode_type
 
 Option = namedtuple('Option', 'option, default, dest, action, help')
 
+
 class EPUB_MOBI(CatalogPlugin):
 
-    'ePub catalog generator'
+    'EPUB catalog generator'
 
     name = 'Catalog_EPUB_MOBI'
-    description = 'AZW3/EPUB/MOBI catalog generator'
+    description = _('AZW3/EPUB/MOBI catalog generator')
     supported_platforms = ['windows', 'osx', 'linux']
     minimum_calibre_version = (0, 7, 40)
     author = 'Greg Riker'
     version = (1, 0, 0)
-    file_types = set(['azw3', 'epub', 'mobi'])
+    file_types = {'azw3', 'epub', 'mobi'}
 
     THUMB_SMALLEST = "1.0"
     THUMB_LARGEST = "2.0"
@@ -41,31 +42,31 @@ class EPUB_MOBI(CatalogPlugin):
                           action=None,
                           help=_('Title of generated catalog used as title in metadata.\n'
                           "Default: '%default'\n"
-                          "Applies to: AZW3, ePub, MOBI output formats")),
+                          "Applies to: AZW3, EPUB, MOBI output formats")),
                    Option('--cross-reference-authors',
                           default=False,
                           dest='cross_reference_authors',
                           action='store_true',
                           help=_("Create cross-references in Authors section for books with multiple authors.\n"
                           "Default: '%default'\n"
-                          "Applies to: AZW3, ePub, MOBI output formats")),
+                          "Applies to: AZW3, EPUB, MOBI output formats")),
                    Option('--debug-pipeline',
                            default=None,
                            dest='debug_pipeline',
                            action=None,
                            help=_("Save the output from different stages of the conversion "
                            "pipeline to the specified "
-                           "directory. Useful if you are unsure at which stage "
+                           "folder. Useful if you are unsure at which stage "
                            "of the conversion process a bug is occurring.\n"
                            "Default: '%default'\n"
-                           "Applies to: AZW3, ePub, MOBI output formats")),
+                           "Applies to: AZW3, EPUB, MOBI output formats")),
                    Option('--exclude-genre',
-                          default='\[.+\]|^\+$',
+                          default=r'\[.+\]|^\+$',
                           dest='exclude_genre',
                           action=None,
                           help=_("Regex describing tags to exclude as genres.\n"
                           "Default: '%default' excludes bracketed tags, e.g. '[Project Gutenberg]', and '+', the default tag for read books.\n"
-                          "Applies to: AZW3, ePub, MOBI output formats")),
+                          "Applies to: AZW3, EPUB, MOBI output formats")),
                    Option('--exclusion-rules',
                           default="(('Catalogs','Tags','Catalog'),)",
                           dest='exclusion_rules',
@@ -78,80 +79,82 @@ class EPUB_MOBI(CatalogPlugin):
                           "will exclude a book with a value of 'Archived' in the custom column 'status'.\n"
                           "When multiple rules are defined, all rules will be applied.\n"
                           "Default: \n" + '"' + '%default' + '"' + "\n"
-                          "Applies to AZW3, ePub, MOBI output formats")),
+                          "Applies to: AZW3, EPUB, MOBI output formats")),
                    Option('--generate-authors',
                           default=False,
                           dest='generate_authors',
                           action='store_true',
                           help=_("Include 'Authors' section in catalog.\n"
                           "Default: '%default'\n"
-                          "Applies to: AZW3, ePub, MOBI output formats")),
+                          "Applies to: AZW3, EPUB, MOBI output formats")),
                    Option('--generate-descriptions',
                           default=False,
                           dest='generate_descriptions',
                           action='store_true',
                           help=_("Include 'Descriptions' section in catalog.\n"
                           "Default: '%default'\n"
-                          "Applies to: AZW3, ePub, MOBI output formats")),
+                          "Applies to: AZW3, EPUB, MOBI output formats")),
                    Option('--generate-genres',
                           default=False,
                           dest='generate_genres',
                           action='store_true',
                           help=_("Include 'Genres' section in catalog.\n"
                           "Default: '%default'\n"
-                          "Applies to: AZW3, ePub, MOBI output formats")),
+                          "Applies to: AZW3, EPUB, MOBI output formats")),
                    Option('--generate-titles',
                           default=False,
                           dest='generate_titles',
                           action='store_true',
                           help=_("Include 'Titles' section in catalog.\n"
                           "Default: '%default'\n"
-                          "Applies to: AZW3, ePub, MOBI output formats")),
+                          "Applies to: AZW3, EPUB, MOBI output formats")),
                    Option('--generate-series',
                           default=False,
                           dest='generate_series',
                           action='store_true',
                           help=_("Include 'Series' section in catalog.\n"
                           "Default: '%default'\n"
-                          "Applies to: AZW3, ePub, MOBI output formats")),
+                          "Applies to: AZW3, EPUB, MOBI output formats")),
                    Option('--generate-recently-added',
                           default=False,
                           dest='generate_recently_added',
                           action='store_true',
                           help=_("Include 'Recently Added' section in catalog.\n"
                           "Default: '%default'\n"
-                          "Applies to: AZW3, ePub, MOBI output formats")),
+                          "Applies to: AZW3, EPUB, MOBI output formats")),
                    Option('--genre-source-field',
                           default=_('Tags'),
                           dest='genre_source_field',
                           action=None,
-                          help=_("Source field for Genres section.\n"
+                          help=_("Source field for 'Genres' section.\n"
                           "Default: '%default'\n"
-                          "Applies to: AZW3, ePub, MOBI output formats")),
+                          "Applies to: AZW3, EPUB, MOBI output formats")),
                    Option('--header-note-source-field',
                           default='',
                           dest='header_note_source_field',
                           action=None,
                           help=_("Custom field containing note text to insert in Description header.\n"
                           "Default: '%default'\n"
-                          "Applies to: AZW3, ePub, MOBI output formats")),
+                          "Applies to: AZW3, EPUB, MOBI output formats")),
                    Option('--merge-comments-rule',
                           default='::',
                           dest='merge_comments_rule',
                           action=None,
                           help=_("#<custom field>:[before|after]:[True|False] specifying:\n"
-                          " <custom field> Custom field containing notes to merge with Comments\n"
-                          " [before|after] Placement of notes with respect to Comments\n"
-                          " [True|False] - A horizontal rule is inserted between notes and Comments\n"
+                          " <custom field> Custom field containing notes to merge with comments\n"
+                          " [before|after] Placement of notes with respect to comments\n"
+                          " [True|False] - A horizontal rule is inserted between notes and comments\n"
                           "Default: '%default'\n"
-                          "Applies to AZW3, ePub, MOBI output formats")),
+                          "Applies to: AZW3, EPUB, MOBI output formats")),
                    Option('--output-profile',
                           default=None,
                           dest='output_profile',
                           action=None,
-                          help=_("Specifies the output profile. In some cases, an output profile is required to optimize the catalog for the device.  For example, 'kindle' or 'kindle_dx' creates a structured Table of Contents with Sections and Articles.\n"  # noqa
-                          "Default: '%default'\n"
-                          "Applies to: AZW3, ePub, MOBI output formats")),
+                          help=_("Specifies the output profile. In some cases, an output profile is required to optimize"
+                                 " the catalog for the device. For example, 'kindle' or 'kindle_dx' creates a structured"
+                                 " Table of Contents with Sections and Articles.\n"
+                                 "Default: '%default'\n"
+                                 "Applies to: AZW3, EPUB, MOBI output formats")),
                    Option('--prefix-rules',
                           default="(('Read books','tags','+','\u2713'),('Wishlist item','tags','Wishlist','\u00d7'))",
                           dest='prefix_rules',
@@ -160,22 +163,22 @@ class EPUB_MOBI(CatalogPlugin):
                           "The model for a prefix rule is ('<rule name>','<source field>','<pattern>','<prefix>').\n"
                           "When multiple rules are defined, the first matching rule will be used.\n"
                           "Default:\n" + '"' + '%default' + '"' + "\n"
-                          "Applies to AZW3, ePub, MOBI output formats")),
+                          "Applies to: AZW3, EPUB, MOBI output formats")),
                    Option('--preset',
                           default=None,
                           dest='preset',
                           action=None,
-                          help=_("Use a named preset created with the GUI Catalog builder.\n"
+                          help=_("Use a named preset created with the GUI catalog builder.\n"
                           "A preset specifies all settings for building a catalog.\n"
                           "Default: '%default'\n"
-                          "Applies to AZW3, ePub, MOBI output formats")),
+                          "Applies to: AZW3, EPUB, MOBI output formats")),
                    Option('--use-existing-cover',
                           default=False,
                           dest='use_existing_cover',
                           action='store_true',
                           help=_("Replace existing cover when generating the catalog.\n"
                           "Default: '%default'\n"
-                          "Applies to: AZW3, ePub, MOBI output formats")),
+                          "Applies to: AZW3, EPUB, MOBI output formats")),
                    Option('--thumb-width',
                           default='1.0',
                           dest='thumb_width',
@@ -183,7 +186,7 @@ class EPUB_MOBI(CatalogPlugin):
                           help=_("Size hint (in inches) for book covers in catalog.\n"
                           "Range: 1.0 - 2.0\n"
                           "Default: '%default'\n"
-                          "Applies to AZW3, ePub, MOBI output formats")),
+                          "Applies to: AZW3, EPUB, MOBI output formats")),
                           ]
     # }}}
 
@@ -262,7 +265,7 @@ class EPUB_MOBI(CatalogPlugin):
 
         build_log = []
 
-        build_log.append(u"%s('%s'): Generating %s %sin %s environment, locale: '%s'" %
+        build_log.append("%s('%s'): Generating %s %sin %s environment, locale: '%s'" %
             (self.name,
              current_library_name(),
              self.fmt,
@@ -280,23 +283,23 @@ class EPUB_MOBI(CatalogPlugin):
         if opts.connected_device['is_device_connected'] and \
            opts.connected_device['kind'] == 'device':
             if opts.connected_device['serial']:
-                build_log.append(u" connected_device: '%s' #%s%s " %
+                build_log.append(" connected_device: '%s' #%s%s " %
                     (opts.connected_device['name'],
                      opts.connected_device['serial'][0:4],
                      'x' * (len(opts.connected_device['serial']) - 4)))
                 for storage in opts.connected_device['storage']:
                     if storage:
-                        build_log.append(u"  mount point: %s" % storage)
+                        build_log.append("  mount point: %s" % storage)
             else:
-                build_log.append(u" connected_device: '%s'" % opts.connected_device['name'])
+                build_log.append(" connected_device: '%s'" % opts.connected_device['name'])
                 try:
                     for storage in opts.connected_device['storage']:
                         if storage:
-                            build_log.append(u"  mount point: %s" % storage)
+                            build_log.append("  mount point: %s" % storage)
                 except:
-                    build_log.append(u"  (no mount points)")
+                    build_log.append("  (no mount points)")
         else:
-            build_log.append(u" connected_device: '%s'" % opts.connected_device['name'])
+            build_log.append(" connected_device: '%s'" % opts.connected_device['name'])
 
         opts_dict = vars(opts)
         if opts_dict['ids']:
@@ -330,12 +333,12 @@ class EPUB_MOBI(CatalogPlugin):
                 opts.log.warn('\n*** No enabled Sections, terminating catalog generation ***')
                 return ["No Included Sections", "No enabled Sections.\nCheck E-book options tab\n'Included sections'\n"]
         if opts.fmt == 'mobi' and sections_list == ['Descriptions']:
-            warning = _("\n*** Adding 'By Authors' Section required for MOBI output ***")
+            warning = _("\n*** Adding 'By authors' section required for MOBI output ***")
             opts.log.warn(warning)
             sections_list.insert(0, 'Authors')
             opts.generate_authors = True
 
-        opts.log(u" Sections: %s" % ', '.join(sections_list))
+        opts.log(" Sections: %s" % ', '.join(sections_list))
         opts.section_list = sections_list
 
         # Limit thumb_width to 1.0" - 2.0"
@@ -395,7 +398,7 @@ class EPUB_MOBI(CatalogPlugin):
 
         if opts.verbose:
             log.info(" Begin catalog source generation (%s)" %
-                     str(datetime.timedelta(seconds=int(time.time() - opts.start_time))))
+                     unicode_type(datetime.timedelta(seconds=int(time.time() - opts.start_time))))
 
         # Launch the Catalog builder
         catalog = CatalogBuilder(db, opts, self, report_progress=notification)
@@ -404,8 +407,8 @@ class EPUB_MOBI(CatalogPlugin):
             catalog.build_sources()
             if opts.verbose:
                 log.info(" Completed catalog source generation (%s)\n"  %
-                         str(datetime.timedelta(seconds=int(time.time() - opts.start_time))))
-        except (AuthorSortMismatchException, EmptyCatalogException), e:
+                         unicode_type(datetime.timedelta(seconds=int(time.time() - opts.start_time))))
+        except (AuthorSortMismatchException, EmptyCatalogException) as e:
             log.error(" *** Terminated catalog generation: %s ***" % e)
         except:
             log.error(" unhandled exception in catalog generator")
@@ -497,7 +500,7 @@ class EPUB_MOBI(CatalogPlugin):
 
             if opts.verbose:
                 log.info(" Catalog creation complete (%s)\n" %
-                     str(datetime.timedelta(seconds=int(time.time() - opts.start_time))))
+                     unicode_type(datetime.timedelta(seconds=int(time.time() - opts.start_time))))
 
         # returns to gui2.actions.catalog:catalog_generated()
         return catalog.error
