@@ -8,14 +8,13 @@ import os
 import re
 import shutil
 import sys
+from calibre_extensions import hunspell
 from collections import defaultdict, namedtuple
 from functools import partial
 from itertools import chain
 
 from calibre import prints
-from calibre.constants import (
-    config_dir, filesystem_encoding, iswindows, plugins
-)
+from calibre.constants import config_dir, filesystem_encoding, iswindows
 from calibre.spell import parse_lang_code
 from calibre.utils.config import JSONConfig
 from calibre.utils.icu import capitalize
@@ -24,9 +23,6 @@ from polyglot.builtins import filter, iteritems, itervalues, map, unicode_type
 
 Dictionary = namedtuple('Dictionary', 'primary_locale locales dicpath affpath builtin name id')
 LoadedDictionary = namedtuple('Dictionary', 'primary_locale locales obj builtin name id')
-hunspell = plugins['hunspell'][0]
-if hunspell is None:
-    raise RuntimeError('Failed to load hunspell: %s' % plugins['hunspell'][1])
 dprefs = JSONConfig('dictionaries/prefs.json')
 dprefs.defaults['preferred_dictionaries'] = {}
 dprefs.defaults['preferred_locales'] = {}
@@ -56,7 +52,8 @@ def builtin_dictionaries():
     if _builtins is None:
         dics = []
         for lc in glob.glob(os.path.join(P('dictionaries', allow_user_override=False), '*/locales')):
-            locales = list(filter(None, open(lc, 'rb').read().decode('utf-8').splitlines()))
+            with open(lc, 'rb') as lcf:
+                locales = list(filter(None, lcf.read().decode('utf-8').splitlines()))
             locale = locales[0]
             base = os.path.dirname(lc)
             dics.append(Dictionary(
@@ -71,7 +68,8 @@ def custom_dictionaries(reread=False):
     if _custom is None or reread:
         dics = []
         for lc in glob.glob(os.path.join(config_dir, 'dictionaries', '*/locales')):
-            locales = list(filter(None, open(lc, 'rb').read().decode('utf-8').splitlines()))
+            with open(lc, 'rb') as cdf:
+                locales = list(filter(None, cdf.read().decode('utf-8').splitlines()))
             try:
                 name, locale, locales = locales[0], locales[1], locales[1:]
             except IndexError:
