@@ -6,11 +6,7 @@
 from datetime import datetime
 
 from dateutil.tz import tzlocal, tzutc, tzoffset
-
-from calibre.constants import plugins
-speedup, err = plugins['speedup']
-if not speedup:
-    raise RuntimeError(err)
+from calibre_extensions import speedup
 
 
 class SafeLocalTimeZone(tzlocal):
