@@ -133,10 +133,24 @@ categories_collapsed_popularity_template = r'{first.count:d} - {last.count:d}'
 # the Tag browser. Items are named using their lookup name, and will be sorted
 # using the number supplied. The lookup name '*' stands for all names that
 # otherwise do not appear. Two names with the same value will be sorted
-# using the default order; the one used when the dict is empty.
-# Example: tag_browser_category_order = {'series':1, 'tags':2, '*':3}
-# resulting in the order series, tags, then everything else in default order.
+# using the default order, the one specified by tag_browser_category_default_sort.
+# Example:
+#   tag_browser_category_order = {'series':1, 'tags':2, '*':3}
+#
+# results in the order series, tags, then everything else in default order.
+# The tweak tag_browser_category_default_sort specifies the sort order before
+# applying the category order from the dict. The allowed values are:
+#   tag_browser_category_default_sort = 'default' # The calibre default order
+#   tag_browser_category_default_sort = 'display_name' # Sort by the display name of the category
+#   tag_browser_category_default_sort = 'lookup_name' # Sort by the lookup name of the category
+#
+# In addition and if the category default sort is not 'default' you can specify
+# whether the sort is ascending or descending. This is ignored if the sort is 'default'.
+#   tag_browser_category_default_sort_direction = 'ascending'
+#   tag_browser_category_default_sort_direction = 'descending'
 tag_browser_category_order = {'*':1}
+tag_browser_category_default_sort = 'default'
+tag_browser_category_default_sort_direction = 'ascending'
 
 
 #: Specify columns to sort the booklist by on startup
@@ -382,11 +396,12 @@ cover_trim_fuzz_value = 10
 # has the side effect of disabling editing a field using a single click.
 # Default: open_viewer.
 # Example: doubleclick_on_library_view = 'do_nothing'
-# You can also control whether the book list scrolls horizontal per column or
-# per pixel. Default is per column.
+# You can also control whether the book list scrolls per item or
+# per pixel. Default is per item.
 doubleclick_on_library_view = 'open_viewer'
 enter_key_behavior = 'do_nothing'
-horizontal_scrolling_per_column = True
+horizontal_scrolling_per_column = False
+vertical_scrolling_per_row = False
 
 #: Language to use when sorting
 # Setting this tweak will force sorting to use the
@@ -573,5 +588,5 @@ skip_network_check = False
 
 #: Tab stop width in the template editor
 # Sets the width of the tab stop in the template editor in "average characters".
-# For example, a value of 1 results in a space the width of one average character.
+# For example, a value of 1 results in a space with the width of one average character.
 template_editor_tab_stop_width = 4
